<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-tw?lang_cible=de
// ** ne pas modifier le fichier **

return [

	// T
	'tw_description' => 'Integration von TextWheel in SPIP',
	'tw_slogan' => 'Typographie in SPIP mit TextWheel steuern',
];
